@@ -1,25 +1,25 @@
 from __future__ import annotations
+
 from typing import Any
-from aiohttp import ClientSession
 
 from linkplay.consts import (
-    ChannelType,
-    LinkPlayCommand,
-    DeviceAttribute,
-    PlayerAttribute,
-    MuteMode,
-    EqualizerMode,
-    LoopMode,
-    PLAY_MODE_SEND_MAP,
-    PlayingStatus,
-    InputMode,
-    SpeakerType,
-    PlayingMode,
     INPUT_MODE_MAP,
+    PLAY_MODE_SEND_MAP,
+    ChannelType,
+    DeviceAttribute,
+    EqualizerMode,
+    InputMode,
+    LinkPlayCommand,
+    LoopMode,
     MultiroomAttribute,
+    MuteMode,
+    PlayerAttribute,
+    PlayingMode,
+    PlayingStatus,
+    SpeakerType,
 )
-
-from linkplay.utils import session_call_api_json, session_call_api_ok, decode_hexstr
+from linkplay.endpoint import LinkPlayEndpoint
+from linkplay.utils import decode_hexstr
 
 
 class LinkPlayDevice:
@@ -44,12 +44,12 @@ class LinkPlayDevice:
     @property
     def uuid(self) -> str:
         """The UUID of the device."""
-        return self.properties[DeviceAttribute.UUID]
+        return self.properties.get(DeviceAttribute.UUID, "")
 
     @property
     def name(self) -> str:
         """The name of the device."""
-        return self.properties[DeviceAttribute.DEVICE_NAME]
+        return self.properties.get(DeviceAttribute.DEVICE_NAME, "")
 
     @property
     def playmode_support(self) -> list[PlayingMode]:
@@ -63,7 +63,11 @@ class LinkPlayDevice:
     @property
     def eth(self) -> str:
         """Returns the ethernet address."""
-        return self.properties[DeviceAttribute.ETH_DHCP]
+        return (
+            self.properties[DeviceAttribute.ETH_DHCP]
+            if DeviceAttribute.ETH_DHCP in self.properties
+            else self.properties[DeviceAttribute.ETH0]
+        )
 
 
 class LinkPlayPlayer:
@@ -147,103 +151,94 @@ class LinkPlayPlayer:
     @property
     def muted(self) -> bool:
         """Returns if the player is muted."""
-        return self.properties[PlayerAttribute.MUTED] == MuteMode.MUTED
+        return self.properties.get(PlayerAttribute.MUTED, MuteMode.UNMUTED) == MuteMode.MUTED
 
     @property
     def title(self) -> str:
         """Returns if the currently playing title of the track."""
-        return self.properties[PlayerAttribute.TITLE]
+        return self.properties.get(PlayerAttribute.TITLE, "")
 
     @property
     def artist(self) -> str:
         """Returns if the currently playing artist."""
-        return self.properties[PlayerAttribute.ARTIST]
+        return self.properties.get(PlayerAttribute.ARTIST, "")
 
     @property
     def album(self) -> str:
         """Returns if the currently playing album."""
-        return self.properties[PlayerAttribute.ALBUM]
+        return self.properties.get(PlayerAttribute.ALBUM, "")
 
     @property
     def volume(self) -> int:
         """Returns the player volume, expressed in %."""
-        return int(self.properties[PlayerAttribute.VOLUME])
+        return int(self.properties.get(PlayerAttribute.VOLUME, 0))
 
     @property
     def current_position(self) -> int:
         """Returns the current position of the track in milliseconds."""
-        return int(self.properties[PlayerAttribute.CURRENT_POSITION])
+        return int(self.properties.get(PlayerAttribute.CURRENT_POSITION, 0))
 
     @property
     def total_length(self) -> int:
         """Returns the total length of the track in milliseconds."""
-        return int(self.properties[PlayerAttribute.TOTAL_LENGTH])
+        return int(self.properties.get(PlayerAttribute.TOTAL_LENGTH, 0))
 
     @property
     def status(self) -> PlayingStatus:
         """Returns the current playing status."""
-        return PlayingStatus(self.properties[PlayerAttribute.PLAYING_STATUS])
+        return PlayingStatus(self.properties.get(PlayerAttribute.PLAYING_STATUS, PlayingStatus.STOPPED))
 
     @property
     def equalizer_mode(self) -> EqualizerMode:
         """Returns the current equalizer mode."""
-        return EqualizerMode(self.properties[PlayerAttribute.EQUALIZER_MODE])
+        return EqualizerMode(self.properties.get(PlayerAttribute.EQUALIZER_MODE, EqualizerMode.CLASSIC))
 
     @property
     def speaker_type(self) -> SpeakerType:
         """Returns the current speaker the player is playing on."""
-        return SpeakerType(self.properties[PlayerAttribute.SPEAKER_TYPE])
+        return SpeakerType(self.properties.get(PlayerAttribute.SPEAKER_TYPE, SpeakerType.MAIN_SPEAKER))
 
     @property
     def channel_type(self) -> ChannelType:
         """Returns the channel the player is playing on."""
-        return ChannelType(self.properties[PlayerAttribute.CHANNEL_TYPE])
+        return ChannelType(self.properties.get(PlayerAttribute.CHANNEL_TYPE, ChannelType.STEREO))
 
     @property
     def play_mode(self) -> PlayingMode:
         """Returns the current playing mode of the player."""
-        return PlayingMode(self.properties[PlayerAttribute.PLAYBACK_MODE])
+        return PlayingMode(self.properties.get(PlayerAttribute.PLAYBACK_MODE, PlayingMode.IDLE))
 
     @property
     def loop_mode(self) -> LoopMode:
         """Returns the current playlist mode."""
-        return LoopMode(self.properties[PlayerAttribute.PLAYLIST_MODE])
+        return LoopMode(self.properties.get(PlayerAttribute.PLAYLIST_MODE, LoopMode.CONTINUOUS_PLAYBACK))
 
 
 class LinkPlayBridge:
     """Represents a LinkPlay bridge to control the device and player attached to it."""
 
-    protocol: str
-    ip_address: str
-    session: ClientSession
+    endpoint: LinkPlayEndpoint
     device: LinkPlayDevice
     player: LinkPlayPlayer
 
-    def __init__(self, protocol: str, ip_address: str, session: ClientSession):
-        self.protocol = protocol
-        self.ip_address = ip_address
-        self.session = session
+    def __init__(self, *, endpoint: LinkPlayEndpoint):
+        self.endpoint = endpoint
         self.device = LinkPlayDevice(self)
         self.player = LinkPlayPlayer(self)
 
-    def __repr__(self) -> str:
+    def __str__(self) -> str:
         if self.device.name == "":
-            return self.endpoint
+            return f"{self.endpoint}"
 
         return self.device.name
 
-    @property
-    def endpoint(self) -> str:
-        """Returns the current player endpoint."""
-        return f"{self.protocol}://{self.ip_address}"
-
     async def json_request(self, command: str) -> dict[str, str]:
         """Performs a GET request on the given command and returns the result as a JSON object."""
-        return await session_call_api_json(self.endpoint, self.session, command)
+        return await self.endpoint.json_request(command)
 
     async def request(self, command: str) -> None:
         """Performs a GET request on the given command and verifies the result."""
-        await session_call_api_ok(self.endpoint, self.session, command)
+        await self.endpoint.request(command)
 
 
 class LinkPlayMultiroom:
